<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';

requireLogin();

// Solo admin o supervisor pueden aprobar
if (!isAdmin() && $_SESSION['user_role'] !== 'supervisor') {
    header('Location: dashboard.php?error=sin_permisos');
    exit();
}

if (!isset($_GET['id'])) {
    header('Location: inspecciones.php?error=id_requerido');
    exit();
}

$inspeccion_id = (int)$_GET['id'];
$inspeccion = new Inspeccion();

// Obtener datos de la inspección
$insp_data = $inspeccion->getById($inspeccion_id);

if (!$insp_data) {
    header('Location: inspecciones.php?error=inspeccion_no_encontrada');
    exit();
}

// Solo se pueden aprobar inspecciones completadas
if ($insp_data['estado'] !== 'completada') {
    header('Location: inspecciones.php?error=solo_completadas');
    exit();
}

$mensaje = '';
$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $accion = $_POST['accion'] ?? '';
    $comentarios_aprobacion = $_POST['comentarios_aprobacion'] ?? '';
    
    try {
        if ($accion === 'aprobar') {
            // Aprobar inspección
            if ($inspeccion->aprobarInspeccion($inspeccion_id, $_SESSION['user_id'], $comentarios_aprobacion)) {
                header('Location: inspecciones.php?success=inspeccion_aprobada');
                exit();
            } else {
                $error = 'Error al aprobar la inspección. Verifica que los campos de aprobación existan en la base de datos.';
            }
        } elseif ($accion === 'rechazar') {
            // Rechazar y devolver a borrador
            if ($inspeccion->rechazarInspeccion($inspeccion_id, $_SESSION['user_id'], $comentarios_aprobacion)) {
                header('Location: inspecciones.php?success=inspeccion_rechazada');
                exit();
            } else {
                $error = 'Error al rechazar la inspección. Verifica que los campos de aprobación existan en la base de datos.';
            }
        }
    } catch (Exception $e) {
        $error = 'Error del sistema: ' . $e->getMessage();
        error_log("Error en aprobar_inspeccion.php: " . $e->getMessage());
    }
}

// Obtener respuestas de la inspección
$respuestas = $inspeccion->getRespuestas($inspeccion_id);
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Aprobar Inspección #<?php echo $inspeccion_id; ?> - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { 
            background-color: #f8f9fa; 
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
        }
        .navbar { 
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); 
        }
        .card { 
            border: none; 
            border-radius: 15px; 
            box-shadow: 0 5px 15px rgba(0,0,0,0.08); 
            margin-bottom: 1.5rem;
        }
        .approval-section {
            background: linear-gradient(135deg, #28a745, #20c997);
            color: white;
            border-radius: 15px;
            padding: 2rem;
            margin-bottom: 2rem;
        }
        .rejection-section {
            background: linear-gradient(135deg, #dc3545, #fd7e14);
            color: white;
            border-radius: 15px;
            padding: 2rem;
            margin-bottom: 2rem;
        }
        .status-badge {
            padding: 8px 16px;
            border-radius: 20px;
            font-weight: 600;
            font-size: 0.9rem;
        }
        .status-completada { background: #d4edda; color: #155724; }
        .btn-approve { background: #28a745; border-color: #28a745; }
        .btn-reject { background: #dc3545; border-color: #dc3545; }
        .debug-info {
            background: #f8f9fa;
            border: 1px solid #dee2e6;
            border-radius: 8px;
            padding: 1rem;
            margin: 1rem 0;
            font-family: monospace;
            font-size: 0.875rem;
        }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <div class="container-fluid">
            <a class="navbar-brand" href="dashboard.php">
                <i class="fas fa-fire-extinguisher me-2"></i><?php echo APP_NAME; ?>
            </a>
            <div class="navbar-nav ms-auto">
                <a class="nav-link" href="debug_aprobacion.php">
                    <i class="fas fa-bug me-2"></i>Debug
                </a>
                <a class="nav-link" href="inspecciones.php">
                    <i class="fas fa-arrow-left me-2"></i>Volver a Inspecciones
                </a>
            </div>
        </div>
    </nav>

    <div class="container-fluid py-4">
        <!-- Header -->
        <div class="row mb-4">
            <div class="col-12">
                <div class="card">
                    <div class="card-body">
                        <div class="d-flex justify-content-between align-items-center">
                            <div>
                                <h2 class="mb-1">
                                    <i class="fas fa-clipboard-check text-primary me-2"></i>
                                    Aprobar Inspección #<?php echo $inspeccion_id; ?>
                                </h2>
                                <p class="text-muted mb-0">
                                    <strong>Inmueble:</strong> <?php echo htmlspecialchars($insp_data['inmueble_nombre']); ?> |
                                    <strong>Inspector:</strong> <?php echo htmlspecialchars($insp_data['inspector_nombre']); ?> |
                                    <strong>Fecha:</strong> <?php echo date('d/m/Y', strtotime($insp_data['fecha_inspeccion'])); ?>
                                </p>
                            </div>
                            <div>
                                <span class="status-badge status-<?php echo $insp_data['estado']; ?>">
                                    <i class="fas fa-check-circle me-1"></i>
                                    <?php echo ucfirst($insp_data['estado']); ?>
                                </span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-triangle me-2"></i><?php echo $error; ?>
            <hr>
            <p class="mb-0">
                <strong>Posibles soluciones:</strong><br>
                1. <a href="debug_aprobacion.php" class="alert-link">Ejecutar diagnóstico del sistema</a><br>
                2. <a href="scripts/15_add_approval_fields_basic.sql" class="alert-link" target="_blank">Ejecutar script SQL básico</a><br>
                3. Contactar al administrador del sistema
            </p>
        </div>
        <?php endif; ?>

        <!-- Resumen de Respuestas -->
        <div class="row mb-4">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h5 class="mb-0">
                            <i class="fas fa-list-check me-2"></i>Resumen de Inspección
                        </h5>
                    </div>
                    <div class="card-body">
                        <?php if (empty($respuestas)): ?>
                            <div class="alert alert-warning">
                                <i class="fas fa-exclamation-triangle me-2"></i>
                                Esta inspección no tiene respuestas registradas.
                            </div>
                        <?php else: ?>
                            <?php
                            $total_respuestas = count($respuestas);
                            $respuestas_si = count(array_filter($respuestas, fn($r) => $r['respuesta'] === 'si'));
                            $respuestas_no = count(array_filter($respuestas, fn($r) => $r['respuesta'] === 'no'));
                            $respuestas_na = count(array_filter($respuestas, fn($r) => $r['respuesta'] === 'na'));
                            ?>
                            <div class="row text-center mb-4">
                                <div class="col-md-3">
                                    <div class="p-3 bg-light rounded">
                                        <h4 class="text-primary"><?php echo $total_respuestas; ?></h4>
                                        <p class="mb-0">Total Elementos</p>
                                    </div>
                                </div>
                                <div class="col-md-3">
                                    <div class="p-3 bg-success bg-opacity-10 rounded">
                                        <h4 class="text-success"><?php echo $respuestas_si; ?></h4>
                                        <p class="mb-0">Conformes</p>
                                    </div>
                                </div>
                                <div class="col-md-3">
                                    <div class="p-3 bg-danger bg-opacity-10 rounded">
                                        <h4 class="text-danger"><?php echo $respuestas_no; ?></h4>
                                        <p class="mb-0">No Conformes</p>
                                    </div>
                                </div>
                                <div class="col-md-3">
                                    <div class="p-3 bg-warning bg-opacity-10 rounded">
                                        <h4 class="text-warning"><?php echo $respuestas_na; ?></h4>
                                        <p class="mb-0">No Aplica</p>
                                    </div>
                                </div>
                            </div>

                            <!-- Mostrar problemas si los hay -->
                            <?php if ($respuestas_no > 0): ?>
                            <div class="alert alert-warning">
                                <h6><i class="fas fa-exclamation-triangle me-2"></i>Elementos No Conformes:</h6>
                                <ul class="mb-0">
                                    <?php foreach ($respuestas as $resp): ?>
                                        <?php if ($resp['respuesta'] === 'no'): ?>
                                        <li>
                                            <strong><?php echo htmlspecialchars($resp['elemento_descripcion']); ?></strong>
                                            <?php if (!empty($resp['observaciones'])): ?>
                                                - <?php echo htmlspecialchars($resp['observaciones']); ?>
                                            <?php endif; ?>
                                        </li>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                            <?php endif; ?>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>

        <!-- Acciones de Aprobación -->
        <div class="row">
            <div class="col-md-6">
                <div class="approval-section">
                    <h4><i class="fas fa-check-circle me-2"></i>Aprobar Inspección</h4>
                    <p>La inspección cumple con los estándares requeridos y puede ser aprobada.</p>
                    
                    <form method="POST" onsubmit="return confirm('¿Estás seguro de que quieres aprobar esta inspección?');">
                        <input type="hidden" name="accion" value="aprobar">
                        <div class="mb-3">
                            <label class="form-label">Comentarios de Aprobación (Opcional)</label>
                            <textarea class="form-control" name="comentarios_aprobacion" rows="3" 
                                      placeholder="Comentarios adicionales sobre la aprobación..."></textarea>
                        </div>
                        <button type="submit" class="btn btn-light btn-lg">
                            <i class="fas fa-check me-2"></i>Aprobar Inspección
                        </button>
                    </form>
                </div>
            </div>
            
            <div class="col-md-6">
                <div class="rejection-section">
                    <h4><i class="fas fa-times-circle me-2"></i>Rechazar Inspección</h4>
                    <p>La inspección requiere correcciones y será devuelta a borrador.</p>
                    
                    <form method="POST" onsubmit="return confirm('¿Estás seguro de que quieres rechazar esta inspección?');">
                        <input type="hidden" name="accion" value="rechazar">
                        <div class="mb-3">
                            <label class="form-label">Motivo del Rechazo (Requerido)</label>
                            <textarea class="form-control" name="comentarios_aprobacion" rows="3" 
                                      placeholder="Especifica qué debe corregirse..." required></textarea>
                        </div>
                        <button type="submit" class="btn btn-light btn-lg">
                            <i class="fas fa-times me-2"></i>Rechazar y Devolver
                        </button>
                    </form>
                </div>
            </div>
        </div>

        <!-- Enlaces adicionales -->
        <div class="row mt-4">
            <div class="col-12 text-center">
                <a href="ver_inspeccion.php?id=<?php echo $inspeccion_id; ?>" class="btn btn-outline-primary me-2">
                    <i class="fas fa-eye me-2"></i>Ver Inspección Completa
                </a>
                <a href="generar_pdf_simple.php?id=<?php echo $inspeccion_id; ?>" class="btn btn-outline-danger me-2" target="_blank">
                    <i class="fas fa-file-pdf me-2"></i>Generar PDF
                </a>
                <a href="debug_aprobacion.php" class="btn btn-outline-warning me-2">
                    <i class="fas fa-bug me-2"></i>Diagnóstico
                </a>
                <a href="inspecciones.php" class="btn btn-outline-secondary">
                    <i class="fas fa-arrow-left me-2"></i>Volver a Inspecciones
                </a>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
