<?php
require_once 'config/database.php';

class Inspeccion {
private $conn;
private $table_name = "inspecciones";

public function __construct() {
    $database = new Database();
    $this->conn = $database->getConnection();
}

public function create($data) {
    $estado = isset($data['estado']) ? $data['estado'] : 'borrador';
    
    $query = "INSERT INTO " . $this->table_name . " 
              (inmueble_id, inspector_id, tipo_inspeccion_id, numero_contrato, fecha_inspeccion, 
               comentarios, contratista_nombre, contratista_direccion, contratista_licencia, estado) 
          VALUES (:inmueble_id, :inspector_id, :tipo_inspeccion_id, :numero_contrato, 
                  :fecha_inspeccion, :comentarios, :contratista_nombre, :contratista_direccion, 
                  :contratista_licencia, :estado)";
    
    $stmt = $this->conn->prepare($query);
    $stmt->bindParam(':inmueble_id', $data['inmueble_id']);
    $stmt->bindParam(':inspector_id', $data['inspector_id']);
    $stmt->bindParam(':tipo_inspeccion_id', $data['tipo_inspeccion_id']);
    $stmt->bindParam(':numero_contrato', $data['numero_contrato']);
    $stmt->bindParam(':fecha_inspeccion', $data['fecha_inspeccion']);
    $stmt->bindParam(':comentarios', $data['comentarios']);
    $stmt->bindParam(':contratista_nombre', $data['contratista_nombre']);
    $stmt->bindParam(':contratista_direccion', $data['contratista_direccion']);
    $stmt->bindParam(':contratista_licencia', $data['contratista_licencia']);
    $stmt->bindParam(':estado', $estado);

    if ($stmt->execute()) {
        return $this->conn->lastInsertId();
    }
    return false;
}

public function saveRespuestas($inspeccion_id, $respuestas) {
    try {
        $this->conn->beginTransaction();

        // Eliminar respuestas existentes
        $delete_query = "DELETE FROM respuestas_inspeccion WHERE inspeccion_id = :inspeccion_id";
        $delete_stmt = $this->conn->prepare($delete_query);
        $delete_stmt->bindParam(':inspeccion_id', $inspeccion_id);
        $delete_stmt->execute();

        // Insertar nuevas respuestas
        $insert_query = "INSERT INTO respuestas_inspeccion (inspeccion_id, elemento_id, respuesta, observaciones) 
                        VALUES (:inspeccion_id, :elemento_id, :respuesta, :observaciones)";
        $insert_stmt = $this->conn->prepare($insert_query);

        foreach ($respuestas as $elemento_id => $data) {
            $insert_stmt->bindParam(':inspeccion_id', $inspeccion_id);
            $insert_stmt->bindParam(':elemento_id', $elemento_id);
            $insert_stmt->bindParam(':respuesta', $data['respuesta']);
            $insert_stmt->bindParam(':observaciones', $data['observaciones']);
            $insert_stmt->execute();

            // Guardar foto si existe
            if (isset($data['foto'])) {
                $foto_query = "INSERT INTO fotos_inspeccion (inspeccion_id, elemento_id, nombre_archivo, ruta_archivo) 
                              VALUES (:inspeccion_id, :elemento_id, :nombre_archivo, :ruta_archivo)";
                $foto_stmt = $this->conn->prepare($foto_query);
                $foto_stmt->bindParam(':inspeccion_id', $inspeccion_id);
                $foto_stmt->bindParam(':elemento_id', $elemento_id);
                $foto_stmt->bindParam(':nombre_archivo', basename($data['foto']));
                $foto_stmt->bindParam(':ruta_archivo', $data['foto']);
                $foto_stmt->execute();
            }
        }

        $this->conn->commit();
        return true;
    } catch (Exception $e) {
        $this->conn->rollback();
        error_log("Error en saveRespuestas: " . $e->getMessage());
        return false;
    }
}

public function getAll() {
    $query = "SELECT i.*, inm.nombre as inmueble_nombre, u.nombre as inspector_nombre, 
                     ti.nombre as tipo_inspeccion_nombre
              FROM " . $this->table_name . " i
              LEFT JOIN inmuebles inm ON i.inmueble_id = inm.id
              LEFT JOIN usuarios u ON i.inspector_id = u.id
              LEFT JOIN tipos_inspeccion ti ON i.tipo_inspeccion_id = ti.id
              ORDER BY i.fecha_inspeccion DESC";
    
    $stmt = $this->conn->prepare($query);
    $stmt->execute();
    
    return $stmt->fetchAll();
}

public function getById($id) {
    $query = "SELECT i.*, inm.nombre as inmueble_nombre, inm.direccion as inmueble_direccion, 
                     inm.telefono as inmueble_telefono, u.nombre as inspector_nombre, 
                     ti.nombre as tipo_inspeccion_nombre
              FROM " . $this->table_name . " i
              LEFT JOIN inmuebles inm ON i.inmueble_id = inm.id
              LEFT JOIN usuarios u ON i.inspector_id = u.id
              LEFT JOIN tipos_inspeccion ti ON i.tipo_inspeccion_id = ti.id
              WHERE i.id = :id";
    
    $stmt = $this->conn->prepare($query);
    $stmt->bindParam(':id', $id);
    $stmt->execute();
    
    return $stmt->fetch();
}

public function getRespuestas($inspeccion_id) {
    $query = "SELECT r.*, e.descripcion as elemento_descripcion, s.nombre as seccion_nombre
              FROM respuestas_inspeccion r
              LEFT JOIN elementos_inspeccion e ON r.elemento_id = e.id
              LEFT JOIN secciones_inspeccion s ON e.seccion_id = s.id
              WHERE r.inspeccion_id = :inspeccion_id
              ORDER BY s.orden, e.orden";
    
    $stmt = $this->conn->prepare($query);
    $stmt->bindParam(':inspeccion_id', $inspeccion_id);
    $stmt->execute();
    
    return $stmt->fetchAll();
}

public function getElementosInspeccion($tipo_inspeccion_id) {
    $query = "SELECT e.*, s.nombre as seccion_nombre, s.orden as seccion_orden
              FROM elementos_inspeccion e
              LEFT JOIN secciones_inspeccion s ON e.seccion_id = s.id
              WHERE s.tipo_inspeccion_id = :tipo_inspeccion_id
              ORDER BY s.orden, e.orden";
    
    $stmt = $this->conn->prepare($query);
    $stmt->bindParam(':tipo_inspeccion_id', $tipo_inspeccion_id);
    $stmt->execute();
    
    return $stmt->fetchAll();
}

public function getEquiposByInmuebleYTipo($inmueble_id, $tipo_inspeccion_id) {
    $query = "SELECT e.*, ti.nombre as tipo_nombre 
             FROM equipos e 
             LEFT JOIN tipos_inspeccion ti ON e.tipo_inspeccion_id = ti.id
             WHERE e.inmueble_id = :inmueble_id AND e.tipo_inspeccion_id = :tipo_inspeccion_id 
             AND e.estado_equipo = 'activo'
             ORDER BY e.codigo_equipo ASC";
    
    $stmt = $this->conn->prepare($query);
    $stmt->bindParam(':inmueble_id', $inmueble_id);
    $stmt->bindParam(':tipo_inspeccion_id', $tipo_inspeccion_id);
    $stmt->execute();
    
    return $stmt->fetchAll();
}

public function saveRespuestasConEquipos($inspeccion_id, $respuestas_equipos) {
    try {
        $this->conn->beginTransaction();

        // Eliminar respuestas existentes
        $delete_query = "DELETE FROM respuestas_inspeccion WHERE inspeccion_id = :inspeccion_id";
        $delete_stmt = $this->conn->prepare($delete_query);
        $delete_stmt->bindParam(':inspeccion_id', $inspeccion_id);
        $delete_stmt->execute();

        // Insertar nuevas respuestas por equipo
        $insert_query = "INSERT INTO respuestas_inspeccion (inspeccion_id, elemento_id, equipo_id, respuesta, observaciones) 
                        VALUES (:inspeccion_id, :elemento_id, :equipo_id, :respuesta, :observaciones)";
        $insert_stmt = $this->conn->prepare($insert_query);

        foreach ($respuestas_equipos as $equipo_id => $elementos) {
            foreach ($elementos as $elemento_id => $data) {
                $insert_stmt->bindParam(':inspeccion_id', $inspeccion_id);
                $insert_stmt->bindParam(':elemento_id', $elemento_id);
                $insert_stmt->bindParam(':equipo_id', $equipo_id);
                $insert_stmt->bindParam(':respuesta', $data['respuesta']);
                $insert_stmt->bindParam(':observaciones', $data['observaciones']);
                $insert_stmt->execute();

                // Guardar foto si existe
                if (isset($data['foto'])) {
                    $foto_query = "INSERT INTO fotos_inspeccion (inspeccion_id, elemento_id, equipo_id, nombre_archivo, ruta_archivo) 
                                  VALUES (:inspeccion_id, :elemento_id, :equipo_id, :nombre_archivo, :ruta_archivo)";
                    $foto_stmt = $this->conn->prepare($foto_query);
                    $foto_stmt->bindParam(':inspeccion_id', $inspeccion_id);
                    $foto_stmt->bindParam(':elemento_id', $elemento_id);
                    $foto_stmt->bindParam(':equipo_id', $equipo_id);
                    $foto_stmt->bindParam(':nombre_archivo', basename($data['foto']));
                    $foto_stmt->bindParam(':ruta_archivo', $data['foto']);
                    $foto_stmt->execute();
                }
            }
        }

        $this->conn->commit();
        return true;
    } catch (Exception $e) {
        $this->conn->rollback();
        error_log("Error en saveRespuestasConEquipos: " . $e->getMessage());
        return false;
    }
}

public function updateEstado($id, $estado) {
    $query = "UPDATE " . $this->table_name . " SET estado = :estado WHERE id = :id";
    
    $stmt = $this->conn->prepare($query);
    $stmt->bindParam(':id', $id);
    $stmt->bindParam(':estado', $estado);

    return $stmt->execute();
}

public function getStatsByUser($user_id) {
    $query = "SELECT 
                COUNT(*) as total,
                SUM(CASE WHEN estado = 'completada' THEN 1 ELSE 0 END) as completadas,
                SUM(CASE WHEN estado = 'borrador' THEN 1 ELSE 0 END) as borradores
              FROM " . $this->table_name . " 
              WHERE inspector_id = :user_id";
    
    $stmt = $this->conn->prepare($query);
    $stmt->bindParam(':user_id', $user_id);
    $stmt->execute();
    
    return $stmt->fetch();
}

public function completarInspeccion($id) {
    try {
        // Actualizar estado a completada
        if ($this->updateEstado($id, 'completada')) {
            // Crear problemas para seguimiento
            require_once 'models/SeguimientoProblemas.php';
            $seguimiento = new SeguimientoProblemas();
            
            // Forzar la creación de problemas
            $resultado = $seguimiento->crearProblemasDesdeInspeccion($id);
            
            if ($resultado) {
                error_log("Problemas creados exitosamente para inspección $id");
            } else {
                error_log("Error al crear problemas para inspección $id");
            }
            
            return true;
        }
        return false;
    } catch (Exception $e) {
        error_log("Error en completarInspeccion: " . $e->getMessage());
        return false;
    }
}

public function getInspeccionesCompletadas() {
    $query = "SELECT i.*, inm.nombre as inmueble_nombre, u.nombre as inspector_nombre
              FROM " . $this->table_name . " i
              LEFT JOIN inmuebles inm ON i.inmueble_id = inm.id
              LEFT JOIN usuarios u ON i.inspector_id = u.id
              WHERE i.estado IN ('completada', 'aprobada')
              ORDER BY i.fecha_inspeccion DESC";
    
    $stmt = $this->conn->prepare($query);
    $stmt->execute();
    
    return $stmt->fetchAll();
}

public function aprobarInspeccion($id, $aprobador_id, $comentarios = '') {
    try {
        // Verificar que los campos existen en la tabla
        $check_query = "SHOW COLUMNS FROM " . $this->table_name . " LIKE 'aprobador_id'";
        $check_stmt = $this->conn->prepare($check_query);
        $check_stmt->execute();
        
        if ($check_stmt->rowCount() == 0) {
            error_log("Campo aprobador_id no existe en la tabla inspecciones");
            return false;
        }
        
        $this->conn->beginTransaction();
        
        // Actualizar estado a aprobada
        $query = "UPDATE " . $this->table_name . " 
                  SET estado = 'aprobada', 
                      aprobador_id = :aprobador_id,
                      fecha_aprobacion = NOW(),
                      comentarios_aprobacion = :comentarios
                  WHERE id = :id AND estado = 'completada'";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':aprobador_id', $aprobador_id);
        $stmt->bindParam(':comentarios', $comentarios);
        
        $result = $stmt->execute();
        
        if ($result && $stmt->rowCount() > 0) {
            $this->conn->commit();
            error_log("Inspección $id aprobada exitosamente por usuario $aprobador_id");
            return true;
        } else {
            $this->conn->rollback();
            error_log("No se pudo aprobar la inspección $id - Filas afectadas: " . $stmt->rowCount());
            return false;
        }
    } catch (Exception $e) {
        $this->conn->rollback();
        error_log("Error en aprobarInspeccion: " . $e->getMessage());
        return false;
    }
}

public function rechazarInspeccion($id, $rechazador_id, $motivo) {
    try {
        // Verificar que los campos existen en la tabla
        $check_query = "SHOW COLUMNS FROM " . $this->table_name . " LIKE 'rechazador_id'";
        $check_stmt = $this->conn->prepare($check_query);
        $check_stmt->execute();
        
        if ($check_stmt->rowCount() == 0) {
            error_log("Campo rechazador_id no existe en la tabla inspecciones");
            return false;
        }
        
        $this->conn->beginTransaction();
        
        // Devolver a borrador con comentarios de rechazo
        $query = "UPDATE " . $this->table_name . " 
                  SET estado = 'borrador', 
                      rechazador_id = :rechazador_id,
                      fecha_rechazo = NOW(),
                      motivo_rechazo = :motivo
                  WHERE id = :id AND estado = 'completada'";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':rechazador_id', $rechazador_id);
        $stmt->bindParam(':motivo', $motivo);
        
        $result = $stmt->execute();
        
        if ($result && $stmt->rowCount() > 0) {
            $this->conn->commit();
            error_log("Inspección $id rechazada exitosamente por usuario $rechazador_id");
            return true;
        } else {
            $this->conn->rollback();
            error_log("No se pudo rechazar la inspección $id - Filas afectadas: " . $stmt->rowCount());
            return false;
        }
    } catch (Exception $e) {
        $this->conn->rollback();
        error_log("Error en rechazarInspeccion: " . $e->getMessage());
        return false;
    }
}

public function getInspeccionesPendientesAprobacion() {
    $query = "SELECT i.*, inm.nombre as inmueble_nombre, u.nombre as inspector_nombre,
                     ti.nombre as tipo_inspeccion_nombre
              FROM " . $this->table_name . " i
              LEFT JOIN inmuebles inm ON i.inmueble_id = inm.id
              LEFT JOIN usuarios u ON i.inspector_id = u.id
              LEFT JOIN tipos_inspeccion ti ON i.tipo_inspeccion_id = ti.id
              WHERE i.estado = 'completada'
              ORDER BY i.fecha_inspeccion DESC";
    
    $stmt = $this->conn->prepare($query);
    $stmt->execute();
    
    return $stmt->fetchAll();
}
}
?>
